==> haskell-stm-hamt-1.2.1.1-92-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-hamt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-hamt
version:              1.2.1.1
visibility:           public
id:                   stm-hamt-1.2.1.1-8KYDGoSTjwIIAlVxNHT3CY
key:                  stm-hamt-1.2.1.1-8KYDGoSTjwIIAlVxNHT3CY
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-hamt
synopsis:             STM-specialised Hash Array Mapped Trie
description:
    A low-level data-structure,
    which can be used to implement higher-level interfaces like
    hash-map and hash-set.
    Such implementations are presented by the
    <http://hackage.haskell.org/package/stm-containers stm-containers>.

category:             Data Structures, STM, Concurrency
abi:                  2cbe354a2ed794ccc4bcc64aa9c19147
exposed:              True
exposed-modules:      StmHamt.Hamt StmHamt.SizedHamt
hidden-modules:
    StmHamt.Constructors.Branch StmHamt.Focuses StmHamt.IntOps
    StmHamt.ListT StmHamt.Prelude StmHamt.Types StmHamt.UnfoldlM

import-dirs:          /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-hamt
hs-libraries:         HSstm-hamt-1.2.1.1-8KYDGoSTjwIIAlVxNHT3CY
depends:
    base-4.17.2.1 deferred-folds-0.9.18.7-tSnwg8dRKP6JfNiz9BUka
    focus-1.0.3.2-CB6vJTM9nWDDWVVswNLZbz
    hashable-1.4.5.0-EdCBZmCkEma7WCMhhvMdNf
    list-t-1.0.5.7-18APWpclSR866rdetdZhfL
    primitive-0.9.1.0-Fzohuuo3yXQHgF9SkKDO4d
    primitive-extras-0.10.2.2-LWoO0JisUdw3CQuoNaGqC4
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-stm-hamt/html/stm-hamt.haddock
haddock-html:         /usr/share/doc/haskell-stm-hamt/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-hamt-1.2.1.1-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-hamt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-hamt
version:              1.2.1.1
visibility:           public
id:                   stm-hamt-1.2.1.1-5XuihmliWtM9XgUg9rcf5n
key:                  stm-hamt-1.2.1.1-5XuihmliWtM9XgUg9rcf5n
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-hamt
synopsis:             STM-specialised Hash Array Mapped Trie
description:
    A low-level data-structure,
    which can be used to implement higher-level interfaces like
    hash-map and hash-set.
    Such implementations are presented by the
    <http://hackage.haskell.org/package/stm-containers stm-containers>.

category:             Data Structures, STM, Concurrency
abi:                  3199c0382d86e95a3aea8e0dfc157bad
exposed:              True
exposed-modules:      StmHamt.Hamt StmHamt.SizedHamt
hidden-modules:
    StmHamt.Constructors.Branch StmHamt.Focuses StmHamt.IntOps
    StmHamt.ListT StmHamt.Prelude StmHamt.Types StmHamt.UnfoldlM

import-dirs:          /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-hamt
hs-libraries:         HSstm-hamt-1.2.1.1-5XuihmliWtM9XgUg9rcf5n
depends:
    base-4.17.2.1 deferred-folds-0.9.18.7-KSORbU2IcgkDVpxu7j8qOn
    focus-1.0.3.2-JxCr0EtQ1XqEqLBTWq7u3t
    hashable-1.4.5.0-tUQ3ISdCwwAzRS3LRBhXn
    list-t-1.0.5.7-AmvYEMuwIfkKmYbfAIQPAl
    primitive-0.9.1.0-F4HGYkgYEkOLs7asiZIPNd
    primitive-extras-0.10.2.2-4L7dnHZQIm0G11RtAZS47A
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-stm-hamt/html/stm-hamt.haddock
haddock-html:         /usr/share/doc/haskell-stm-hamt/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
